@@ -70,6 +70,7 @@
 //! parz.finish().unwrap();
 //! # }
 //! ```
+#![allow(clippy::missing_panics_doc, clippy::missing_errors_doc)]
 use std::fmt::Debug;
 use std::io::{self, Write};
 use std::marker::PhantomData;
@@ -86,6 +87,9 @@ use crate::check::Check;
 use crate::par::compress::ParCompressBuilder;
 use crate::syncz::{SyncZ, SyncZBuilder};
 
+pub use crate::bgzf::{BgzfSyncReader, BgzfSyncWriter};
+pub use crate::mgzip::{MgzipSyncReader, MgzipSyncWriter};
+
 mod bgzf;
 pub mod check;
 #[cfg(feature = "deflate")]
@@ -161,7 +165,7 @@ pub trait ZWriter: Write {
 }
 
 /// Create a synchronous writer wrapping the input `W` type.
-pub trait SyncWriter<W: Write> {
+pub trait SyncWriter<W: Write>: Send {
     // type InputWriter: Write;
     type OutputWriter: Write;
 
@@ -175,6 +179,7 @@ where
     W: Write + Send + 'static,
 {
     num_threads: usize,
+    pin_threads: Option<usize>,
     compression_level: Compression,
     buffer_size: usize,
     writer: PhantomData<W>,
@@ -189,6 +194,7 @@ where
     pub fn new() -> Self {
         Self {
             num_threads: num_cpus::get(),
+            pin_threads: None,
             compression_level: Compression::new(3),
             buffer_size: F::DEFAULT_BUFSIZE,
             writer: PhantomData,
@@ -207,6 +213,12 @@ where
         self
     }
 
+    /// Whether or not to pin compression threads and which physical CPU to start pinning at.
+    pub fn pin_threads(mut self, pin_threads: Option<usize>) -> Self {
+        self.pin_threads = pin_threads;
+        self
+    }
+
     /// Buffer size to use (the effect of this may vary depending on `F`),
     /// check the documentation on the `F` type you are creating to see if
     /// there are restrictions on the buffer size.
@@ -219,7 +231,7 @@ where
     #[allow(clippy::missing_panics_doc)]
     pub fn from_writer(self, writer: W) -> Box<dyn ZWriter>
     where
-        SyncZ<<F as SyncWriter<W>>::OutputWriter>: ZWriter,
+        SyncZ<<F as SyncWriter<W>>::OutputWriter>: ZWriter + Send,
     {
         if self.num_threads > 1 {
             Box::new(
@@ -229,6 +241,7 @@ where
                     .unwrap()
                     .buffer_size(self.buffer_size)
                     .unwrap()
+                    .pin_threads(self.pin_threads)
                     .from_writer(writer),
             )
         } else {
